pub enum Bias {
GreatestLowerBound,
LeastUpperBound,
}Expand description
Search bias for position lookups.
Controls how non-exact matches are resolved during binary search:
GreatestLowerBound(default): find the closest mapping at or before the positionLeastUpperBound: find the closest mapping at or after the position
Variants
GreatestLowerBound
Return the closest position at or before the requested position (default).
LeastUpperBound
Return the closest position at or after the requested position.