Module js_identifiers

Module js_identifiers 

JavaScript identifier validation utilities.

Provides functions to check whether a string is a valid JavaScript identifier and to extract the first identifier token from a source line.

Functions

get_javascript_token
Extract the first valid JavaScript identifier from a source line.
is_valid_javascript_identifier
Check if a string is a valid JavaScript identifier.