pub struct RawSourceMapLite<'a> {
pub version: u32,
pub file: Option<String>,
pub source_root: Option<String>,
pub sources: Vec<Option<String>>,
pub names: Vec<String>,
pub mappings: &'a str,
pub ignore_list: Option<Vec<u32>>,
pub x_google_ignore_list: Option<Vec<u32>>,
pub debug_id: Option<String>,
pub scopes: Option<&'a str>,
pub range_mappings: Option<&'a str>,
pub sections: Option<Vec<Value>>,
}Expand description
Lightweight version that skips sourcesContent allocation. Used by WASM bindings where sourcesContent is kept JS-side.
Note: Indexed/sectioned source maps are detected via the sections field
and must be rejected by callers (LazySourceMap does not support them).
Fields
version: u32file: Option<String>source_root: Option<String>sources: Vec<Option<String>>names: Vec<String>mappings: &'a strignore_list: Option<Vec<u32>>x_google_ignore_list: Option<Vec<u32>>debug_id: Option<String>scopes: Option<&'a str>range_mappings: Option<&'a str>sections: Option<Vec<Value>>Indexed source maps use sections instead of mappings.
Presence is checked to reject indexed maps in lazy parse paths.